OC.L10N.register(
    "files_trashbin",
    {
    "Deleted files" : "eyddar skrár",
    "restored" : "endurheimt",
    "This application enables users to restore files that were deleted from the system." : "Þetta forrit gerir notendum kleift að endurheimta skrár sem eytt hefur verið af kerfinu.",
    "Restore" : "Endurheimta",
    "Delete permanently" : "Eyða varanlega",
    "This operation is forbidden" : "Þessi aðgerð er bönnuð",
    "This directory is unavailable, please check the logs or contact the administrator" : "Þessi mappa er ekki tiltæk, athugaðu atvikaskrár eða hafðu samband við kerfissjóra",
    "No deleted files" : "Engar eyddar skrár",
    "You will be able to recover deleted files from here" : "Þú getur endurheimt eyddar skrár héðan",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Select all" : "Velja allt",
    "Name" : "Heiti",
    "Actions" : "Aðgerðir",
    "Deleted" : "Eytt",
    "Delete" : "Eyða",
    "Error while restoring file from trashbin" : "Villa við að endurheimta skrá úr ruslafötunni",
    "Error while removing file from trashbin" : "Villa við að fjarlægja skrá úr ruslafötunni",
    "Error while restoring files from trashbin" : "Villa við að endurheimta skrár úr ruslafötunni",
    "Error while emptying trashbin" : "Villa við að tæma ruslafötuna",
    "Error while removing files from trashbin" : "Villa við að fjarlægja skrár úr ruslafötunni"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
